@@ -5,6 +5,8 @@ int* malloc_int(int n);
 int **matrixINT(int n, int m);
 void matrixINTcpy(int **A, int **B, int n, int m);
 void free_matrixINT(int **A, int n);
+/* float unif(); */
+int int_unif(int n);
 
 extern const double INF;
 
